<?php
	/*
	 *		Modal Popup for Wizard Configuration
	 *
	 *	The ordered steps during the Wizard Configuration:
	 *	
	 *		A. Network Settings	: setting the network configuration; LAN- or LAN-WAN-Mode
	 *					  (IP-Address, Netmask, Gateway, DNS-Server, ...)
	 *		B. Gateway Scenarios	: selecting the Wizard Gateway configuration
	 *					  (VoIP-Gateway, VoIP-PBX, VoIP-Provider, VoIP-Manual, ...)
	 *		C. SIP Settings		: setting the SIP-settings
	 * 					  (Name, Server-Address, Registration, ...)
	 *		D. PSTN Settings 	: setting the PRI modules
	 *					  (Group Name, Ports, Protocol, ...)
	 *		E. Summary/Activate 	: resume the previous settings. Set 'Activate'-button to save
	 *					  the previous configuration and start the factory reset
	 *
	 *	Sections for the following script:
	 *
	 *		1. INIT		: init the wizard_popup script loading class, variables and lang
	 *		2. FUNCTIONS	: functions used by the next sections
	 *		3. NETWORK	: configure and write the Network Settings string 
	 *		4. SCENARIOS	: configure and write the Scenarios string
	 * 		5. SIP_SECTION	: configure and write the Sip Settings string
	 * 		6. PRI_SECTION	: configure and write the Pri Settings string
	 * 		7. ACTIVATE	: summarize and activate the Settings
	 *
	 */

// TODO: SAME BUTTON BEHAVIOR THAN USUAL GATEWAY BUTTONS WHEN A FIELD IS REQUIRED
// TODO: in the input field, forbid to use characters like '<' or '>' to forbid javascript input

############################################### INIT #########################################
chdir("../..");

include ("./misc/database.php");
include ("./includes/variables.php");
include ("./misc/config_parameter.php");

$ba = new beroAri();

require_once ('./includes/lang.php');
require_once ('./includes/session.php');

######################################################## FUNCTIONS  #################################################################
function get_test_command_value ($cmd)
{
	exec($cmd, $output, $retval);
	return (($retval == 0) ? 1 : 0);
}

function display_internet_connection_message()
{
	//check internet connection
	$dns_on    = get_test_command_value('/bin/grep nameserver /etc/resolv.conf');
	$dns_works = get_test_command_value('/bin/ping -c 1 beronet.com');

	if (!($dns_on && $dns_works))
	{
		return '<div id="security_mess" class="text-center" style="margin-top:5px; color:red;">'. WIZARD_POPUP_NO_INTERNET_CONNECTION .'</div>'. "\n";
	}

	return '';
}

function update_save_wizard_cfg($save_setting, $configuration, $newparameters, $filename)
{
	// Update data 
	foreach ($newparameters as $parameter => $value)
	{
		$configuration[$save_setting][$parameter] = $value;
	}

	// Save data
	$wizard_str = '';
	foreach ($configuration as $settings => $parameters)
	{
		$wizard_str .= '['. $settings ."]\n";
		foreach ($parameters as $parameter => $value)
		{
			if (strlen($value) > 0)
			{
				$wizard_str .= "$parameter=$value\n";
			}
		}
	}

	$fp = fopen($filename, "w+");
	fputs($fp, html_entity_decode($wizard_str));
	fclose($fp);
	
	return $configuration;
}

// Main displaying functions 
function display_modal_windows ($name, $title, $content)
{
	$html_str = '';
	ob_start();
?>
<p class='text-center h4'><?php echo $title; ?></p>
<form class='form-horizontal' method='GET' style='margin-top: 10px;' name='<?php echo $name; ?>' id='<?php echo $name; ?>form'>
	<div class='tab-content' style='border-top: 1px solid #ddd;'>
		<div role='tabpanel' class='tab-pane active' id='id<?php echo $name; ?>'>
<?php echo $content; ?>
		</div>
	</div>
</form>
<div class='text-center' style='margin: 10px;'><i><?php echo REQUIRED_FIELDS; ?></i></div>
<?php
	$html_str = 	  ob_get_clean()
			. display_bottom_buttons($name);

	return $html_str;
}

function display_javascript_code ($oldpage, $currentpage, $newpage, $list_ids)
{
	$url 		= '';
	$def_variables 	= '';

	foreach ($list_ids as $url_id => $array)
	{
		if (isset($array['id']))
		{
			$getBy 		= 'ById';
			$getElement 	= $array['id'];

			$def_variables .= "\t\tvar var$url_id  = document.getElement$getBy('$getElement'){$array['object']};\n";
		}
		else 
		{
			$getBy 		= 'sByName';
			$getElement 	= $array['name'];

			$def_variables .= 	  "\n"
						. "\t\tvar var$url_id = \"\";\n"
						. "\t\tfor(var valueNode of document.getElement$getBy('$getElement').values())\n" 
						. "\t\t{\n"
						. "\t\t\tif (valueNode.checked)\n"
						. "\t\t\t{\n"
						. "\t\t\t\tvar$url_id += valueNode.value.toString() + '-';\n"
						. "\t\t\t}\n"
						. "\t\t}\n\n";
		
			$i++;
		}

		$url .= "&$url_id=' + var$url_id + '";
	}

	if (strcmp($currentpage, 'Activate') == 0) 
	{
		$javascript_code =	  "\tfunction activateWizard ()\n"
					. "\t{\n"
					. "\t\twindow.location.href = 'modules/RebootReset/recreate.php?wizard=1';\n"
					. "\t}\n\n";
	}
	else 
	{
		$javascript_code = 	  "\tfunction goToNextSettings ()\n"
					. "\t{\n"
					. $def_variables
					. ' '				// tricky line to have a better view on the View Souce from the browser page
					. "\t\t$('.modal-body').load('modules/Wizard/wizard_popup.php?settings=$newpage$url');\n"
					. "\t}\n";
	}

	ob_start();
?>
<script type="text/javascript">
<?php	echo $javascript_code; ?>

	function goToPreviousSettings ()
	{
		$('.modal-body').load('modules/Wizard/wizard_popup.php?previous=1&settings=<?php echo $oldpage; ?>');
	}

	$(document).ready(function () 
	{
		$('[data-toggle="tooltip"]').tooltip({placement: 'auto bottom', html: true, trigger: 'hover', contenter: 'body'});
	});
</script>
<?php
	return ob_get_clean() . "\n";
}

function display_bottom_buttons ($current_modal)
{
	$button_next 	= BUTTON_NEXT;
	$onclick_next 	= 'onclick="goToNextSettings();"';
	
	if (strcmp($current_modal, 'Activate') == 0)
	{
		$button_next	= BUTTON_ACTIVATE;
		$onclick_next	= 'onclick="activateWizard();"';
	}

	$button_previous = "\t<a role='button' class='btn btn-default' style='margin-right: 4px;' onclick=\"goToPreviousSettings();\">". BUTTON_PREVIOUS ."</a>\n";

	if (strcmp($current_modal, 'Network') == 0)
	{
		$button_previous = '';
	}	

	$html_str = 	  "<div class='text-center'>\n"
			. $button_previous
			. "\t<a role='button' data-remote='false' data-toggle='modal' data-target='#reset-popup' class='btn btn-default' style='margin-right: 4px;'>". BUTTON_CANCEL ."</a>\n"
			. "\t<a role='button' class='btn btn-default' style='margin-right: 4px;' $onclick_next>$button_next</a>\n"
			. "</div>\n\n";

	return $html_str;
}

######################################################## MAIN MODAL POPUP SECTION #################################################################
// init general variables
$bool_settings 	  = false;

$previous_modal   = '';
$current_modal 	  = '';
$next_modal 	  = '';

$title_modal 	  = '';
$content_modal	  = '';

$message 	  = '';
$extra_javascript = '';

$ids_array 	  = 	array();

$flow_settings 	  = 	array(	'Network' 	=> array( 'previous' => 'Configuration'	, 'next' => 'Scenarios'	, 'title' => WIZARD_NETWORK_TITLE_DIS	),
				'Scenarios' 	=> array( 'previous' => 'Network'	, 'next' => 'Sip'	, 'title' => WIZARD_SCENARIOS_TITLE_DIS	),
				'Sip' 		=> array( 'previous' => 'Scenarios' 	, 'next' => 'Pstn'	, 'title' => WIZARD_SIP_TITLE_DIS	),
				'Pstn'		=> array( 'previous' => 'Sip'		, 'next' => 'Activate'	, 'title' => WIZARD_PSTN_TITLE_DIS	),
				'Activate'	=> array( 'previous' => 'Pstn'		, 'next' => ''		, 'title' => WIZARD_ACTIVATE_TITLE_DIS	));	

// get settings parameter
if (isset($_GET['settings']))
{
	$current_modal 	= $_GET['settings'];

	$title_modal 	= $flow_settings[$current_modal]['title'];
	$previous_modal = $flow_settings[$current_modal]['previous'];
	$next_modal 	= $flow_settings[$current_modal]['next'];

	unset($_GET['settings']);
}

/* Load data only if $current_modal > 'Network' (in case where a cancel choice has been made) */
$wizard_cfg 	= array();
$filename 	= '/tmp/wizard.cfg';

// TODO: uncomment the condition
if (file_exists($filename) /*&& ((strcmp($current_modal, 'Network') != 0) || (isset($_GET['previous']) && $_GET['previous']))*/)
{
	$wizard_cfg = parse_ini_file($filename, true);
}
unset($_GET['previous']);

/* Update and Save the data */
$wizard_cfg = update_save_wizard_cfg($previous_modal, $wizard_cfg, $_GET, $filename);

/* NETWORK - set Network Settings popup */
if (strcmp($current_modal, 'Network') == 0)
{
	$bc = new beroConf('root');
	if (!($bc -> valid()))
	{
		$message = 'RED ERROR';
	}

	require_once('./modules/Wizard/network_wizard_popup.php');	
	$networkWizard = new NetworkWizard();

	$saveNet = isset($wizard_cfg['Configuration']['saveNet']) && ($wizard_cfg['Configuration']['saveNet'] == 'true' || $wizard_cfg['Configuration']['saveNet'] == 1);
	
	$ids_array 	  = $networkWizard -> get_ids_array();
	$content_modal 	  = $networkWizard -> get_content_modal( $saveNet, $bc, isset($wizard_cfg['Network']) ? $wizard_cfg['Network'] : array() );
	$extra_javascript = $networkWizard -> get_javascript_code();

	$bool_settings = true;
}

/* SCENARIOS - Set the VoIP Scenarios */
if (strcmp($current_modal, 'Scenarios') == 0)
{
	require_once('./modules/Wizard/scenarios_wizard_popup.php');
	$scenariosWizard = new ScenariosWizard();

	$ids_array 	= $scenariosWizard -> get_ids_array();
	$content_modal  = $scenariosWizard -> get_content_modal( isset($wizard_cfg['Scenarios']) ? $wizard_cfg['Scenarios'] : array() );

	$bool_settings = true;
}

/* SIP_SECTION - set Sip Settings popup */
if (strcmp($current_modal, 'Sip') == 0)
{
	$scenario = 1;
	if (isset($wizard_cfg['Scenarios']['Pbx']) && ($wizard_cfg['Scenarios']['Pbx'] == 'true' || $wizard_cfg['Scenarios']['Pbx'] == 1))
	{
		$scenario = 2;
	}
	else if (isset($wizard_cfg['Scenarios']['Provider']) && ($wizard_cfg['Scenarios']['Provider'] == 'true' || $wizard_cfg['Scenarios']['Provider'] == 1))
	{
		$scenario = 3;
	}
	else if (isset($wizard_cfg['Scenarios']['Manual']) && ($wizard_cfg['Scenarios']['Manual'] == 'true' || $wizard_cfg['Scenarios']['Manual'] == 1))
	{
		$scenario = 4;
	}

	require_once('./modules/Wizard/sip_wizard_popup.php');
	$sipWizard = new SipWizard(true, $scenario);

	$ids_array	  = $sipWizard -> get_ids_array();
	$content_modal	  = $sipWizard -> get_content_modal($ba, isset($wizard_cfg['Sip']) ? $wizard_cfg['Sip'] : array() );
	$extra_javascript = $sipWizard -> get_javascript_code();	

	$bool_settings = true;
}

/* PSTN_SECTION - set PTSN Settings popup */
if (strcmp($current_modal, 'Pstn') == 0)
{
	require_once('./modules/Wizard/pstn_wizard_popup.php');
	$pstnWizard = new PstnWizard();

	$ids_array 	  = $pstnWizard -> get_ids_array();
	$content_modal 	  = $pstnWizard -> get_content_modal($ba, isset($wizard_cfg['Pstn']) ? $wizard_cfg['Pstn'] : array() );
	$extra_javascript = $pstnWizard -> get_javascript_code(isset($wizard_cfg['Pstn']['PSTN_header']) ? $wizard_cfg['Pstn']['PSTN_header'] : '');

	$bool_settings = true;
}

/* ACTIVATE - Activate the Settings */
if (strcmp($current_modal, 'Activate') == 0)
{
	require_once('./modules/Wizard/activate_wizard_popup.php');
	$activateWizard = new ActivateWizard($ba, $wizard_cfg);

	$dialplan_rules = $activateWizard -> get_dialplan_rules();

	// save Dialplan Rules
	update_save_wizard_cfg('Dialplan', $wizard_cfg, $dialplan_rules, $filename);

	$content_modal = $activateWizard -> get_modal_content();

	$bool_settings = true;
}

if ($bool_settings)
{
	// display the modal content
	$html_str .= 	  display_internet_connection_message()
			. $message
			. display_javascript_code($previous_modal, $current_modal, $next_modal, $ids_array)
			. display_modal_windows($current_modal, strtoupper($title_modal), $content_modal)
			. $extra_javascript;

	echo $html_str;

	return 1;
}

echo 'Wrong URL';
return 0;
?>
